@@ -1,22 +1,21 @@
-/* Copyright (C) 1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,
- *   2005,2006,2007,2008,2009,2010,2011,2012,2013,2014
- * Free Software Foundation, Inc.
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-2019
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -27,47 +26,52 @@
 #include <alloca.h>
 #include <stdarg.h>
 
-#include "libguile/__scm.h"
+#include "alist.h"
+#include "async.h"
+#include "boolean.h"
+#include "continuations.h"
+#include "control.h"
+#include "debug.h"
+#include "deprecation.h"
+#include "dynwind.h"
+#include "eq.h"
+#include "expand.h"
+#include "feature.h"
+#include "frames.h"
+#include "fluids.h"
+#include "goops.h"
+#include "gsubr.h"
+#include "hash.h"
+#include "hashtab.h"
+#include "keywords.h"
+#include "list.h"
+#include "macros.h"
+#include "memoize.h"
+#include "modules.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "ports.h"
+#include "print.h"
+#include "private-options.h"
+#include "procprop.h"
+#include "programs.h"
+#include "smob.h"
+#include "srcprop.h"
+#include "stackchk.h"
+#include "strings.h"
+#include "symbols.h"
+#include "threads.h"
+#include "throw.h"
+#include "values.h"
+#include "variable.h"
+#include "vectors.h"
+#include "vm.h"
 
-#include "libguile/_scm.h"
-#include "libguile/alist.h"
-#include "libguile/async.h"
-#include "libguile/continuations.h"
-#include "libguile/control.h"
-#include "libguile/debug.h"
-#include "libguile/deprecation.h"
-#include "libguile/dynwind.h"
-#include "libguile/eq.h"
-#include "libguile/expand.h"
-#include "libguile/feature.h"
-#include "libguile/goops.h"
-#include "libguile/hash.h"
-#include "libguile/hashtab.h"
-#include "libguile/list.h"
-#include "libguile/macros.h"
-#include "libguile/memoize.h"
-#include "libguile/modules.h"
-#include "libguile/ports.h"
-#include "libguile/print.h"
-#include "libguile/procprop.h"
-#include "libguile/programs.h"
-#include "libguile/smob.h"
-#include "libguile/srcprop.h"
-#include "libguile/stackchk.h"
-#include "libguile/strings.h"
-#include "libguile/threads.h"
-#include "libguile/throw.h"
-#include "libguile/validate.h"
-#include "libguile/values.h"
-#include "libguile/vectors.h"
-#include "libguile/vm.h"
+#include "eval.h"
 
-#include "libguile/eval.h"
-#include "libguile/private-options.h"
 
 
 
-
 /* We have three levels of EVAL here:
 
    - eval (exp, env)
@@ -197,22 +201,22 @@ env_set (SCM env, int depth, int width, SCM val)
 
 static void error_missing_value (SCM proc, SCM kw)
 {
-  scm_error_scm (scm_from_latin1_symbol ("keyword-argument-error"), proc,
-                 scm_from_locale_string ("Keyword argument has no value"), SCM_EOL,
+  scm_error_scm (scm_from_utf8_symbol ("keyword-argument-error"), proc,
+                 scm_from_utf8_string ("Keyword argument has no value"), SCM_EOL,
                  scm_list_1 (kw));
 }
 
 static void error_invalid_keyword (SCM proc, SCM obj)
 {
-  scm_error_scm (scm_from_latin1_symbol ("keyword-argument-error"), proc,
-                 scm_from_locale_string ("Invalid keyword"), SCM_EOL,
+  scm_error_scm (scm_from_utf8_symbol ("keyword-argument-error"), proc,
+                 scm_from_utf8_string ("Invalid keyword"), SCM_EOL,
                  scm_list_1 (obj));
 }
 
 static void error_unrecognized_keyword (SCM proc, SCM kw)
 {
-  scm_error_scm (scm_from_latin1_symbol ("keyword-argument-error"), proc,
-                 scm_from_locale_string ("Unrecognized keyword"), SCM_EOL,
+  scm_error_scm (scm_from_utf8_symbol ("keyword-argument-error"), proc,
+                 scm_from_utf8_string ("Unrecognized keyword"), SCM_EOL,
                  scm_list_1 (kw));
 }
 
@@ -221,18 +225,17 @@ static void error_unrecognized_keyword (SCM proc, SCM kw)
 static SCM
 truncate_values (SCM x)
 {
-  if (SCM_LIKELY (!SCM_VALUESP (x)))
+  if (SCM_LIKELY (!scm_is_values (x)))
     return x;
   else
     {
-      SCM l = scm_struct_ref (x, SCM_INUM0);
-      if (SCM_LIKELY (scm_is_pair (l)))
-        return scm_car (l);
+      if (SCM_LIKELY (scm_i_nvalues (x) > 0))
+        return scm_i_value_ref (x, 0);
       else
         {
-          scm_ithrow (scm_from_latin1_symbol ("vm-run"),
-                      scm_list_3 (scm_from_latin1_symbol ("vm-run"),
-                                  scm_from_locale_string
+          scm_ithrow (scm_from_utf8_symbol ("vm-run"),
+                      scm_list_3 (scm_from_utf8_symbol ("vm-run"),
+                                  scm_from_utf8_string
                                   ("Too few values returned to continuation"),
                                   SCM_EOL),
                       1);
@@ -365,8 +368,13 @@ eval (SCM x, SCM env)
         /* `proc' is the consumer.  */
         proc = EVAL1 (CDR (mx), env);
         v = scm_call_0 (producer);
-        if (SCM_VALUESP (v))
-          args = scm_struct_ref (v, SCM_INUM0);
+        if (scm_is_values (v))
+          {
+            size_t i = scm_i_nvalues (v);
+            args = SCM_EOL;
+            while (i--)
+              args = scm_cons (scm_i_value_ref (v, i), args);
+          }
         else
           args = scm_list_1 (v);
         goto apply_proc;
@@ -428,40 +436,41 @@ eval (SCM x, SCM env)
 
     case SCM_M_CALL_WITH_PROMPT:
       {
-        struct scm_vm *vp;
+        scm_thread *t;
         SCM k, handler, res;
-        scm_i_jmp_buf registers;
-        const void *prev_cookie;
-        scm_t_ptrdiff saved_stack_depth;
+        jmp_buf registers;
+        jmp_buf *prev_registers;
+        ptrdiff_t saved_stack_depth;
+        uint8_t *mra = NULL;
 
         k = EVAL1 (CAR (mx), env);
         handler = EVAL1 (CDDR (mx), env);
-        vp = scm_the_vm ();
+        t = SCM_I_CURRENT_THREAD;
 
-        saved_stack_depth = vp->stack_top - vp->sp;
+        saved_stack_depth = t->vm.stack_top - t->vm.sp;
 
         /* Push the prompt onto the dynamic stack. */
-        scm_dynstack_push_prompt (&SCM_I_CURRENT_THREAD->dynstack,
+        scm_dynstack_push_prompt (&t->dynstack,
                                   SCM_F_DYNSTACK_PROMPT_ESCAPE_ONLY,
                                   k,
-                                  vp->stack_top - vp->fp,
+                                  t->vm.stack_top - t->vm.fp,
                                   saved_stack_depth,
-                                  vp->ip,
+                                  t->vm.ip, mra,
                                   &registers);
 
-        prev_cookie = vp->resumable_prompt_cookie;
-        if (SCM_I_SETJMP (registers))
+        prev_registers = t->vm.registers;
+        if (setjmp (registers))
           {
             /* The prompt exited nonlocally. */
-            vp->resumable_prompt_cookie = prev_cookie;
+            t->vm.registers = prev_registers;
             scm_gc_after_nonlocal_exit ();
             proc = handler;
-            args = scm_i_prompt_pop_abort_args_x (vp, saved_stack_depth);
+            args = scm_i_prompt_pop_abort_args_x (&t->vm, saved_stack_depth);
             goto apply_proc;
           }
         
         res = scm_call_0 (eval (CADR (mx), env));
-        scm_dynstack_pop (&SCM_I_CURRENT_THREAD->dynstack);
+        scm_dynstack_pop (&t->dynstack);
         return res;
       }
 
@@ -969,12 +978,5 @@ scm_init_eval ()
   var_primitive_eval = scm_define (SCM_SUBR_NAME (primitive_eval),
                                    primitive_eval);
 
-#include "libguile/eval.x"
+#include "eval.x"
 }
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
-
